@@ -1,21 +1,32 @@
 # coding=utf-8
+import abc
 from configparser import ConfigParser
-from typing import Dict
+# from typing import List, Dict
 
 import yaml
 
 
-class YamlLoader:
+# Context = Dict[str, 'Context'] | List['Context'] | str | int | float | bool | None
+
+
+# noinspection PyUnusedLocal
+class StrLoader(object):
+    @abc.abstractmethod
+    def load(self, content: str):
+        return {}
+
+
+class YamlLoader(StrLoader):
     # noinspection PyMethodMayBeStatic
-    def load(self, content: str) -> Dict[str, Dict[str, str]]:
+    def load(self, content: str):
         return yaml.safe_load(content)
 
 
-class IniLoader:
+class IniLoader(StrLoader):
     def __init__(self):
         self._parser = ConfigParser()
 
-    def load(self, content: str) -> Dict[str, Dict[str, str]]:
+    def load(self, content: str):
         self._parser.read_string(content)
         return {
             section: dict(self._parser.items(section))
