@@ -5,16 +5,15 @@ import os
 import queue  # using python-future for 2/3 compatibility
 import threading
 import time
-
-# noinspection PyCompatibility,PyPackageRequirements
-from typing import List, Dict
+from typing import Any, List, Dict
 from urllib.request import OpenerDirector
 
 import deprecation
-import yaml
+# noinspection PyPackageRequirements
 from pydantic import BaseModel
 
 from kebab.constants import DEFAULT_URL_ENVVAR, DISABLE_RELOAD
+from kebab.loader import YamlLoader, StrLoader
 from kebab.openers import DEFAULT_OPENER
 from kebab.utils import (
     update_recursively,
@@ -39,7 +38,7 @@ class ContextExtension(object):
 
 
 class KebabSource(dict):
-    _context_extensions = {}  # type: Dict[str, ContextExtension]
+    _context_extensions: Dict[str, ContextExtension] = {}
 
     @classmethod
     def register_extension(cls, extension):
@@ -48,6 +47,14 @@ class KebabSource(dict):
         if isinstance(extension, ContextExtension):
             KebabSource._context_extensions[extension.keyword] = extension
 
+    @property
+    def str_loader(self, ) -> StrLoader:
+        return self._str_loader
+
+    @str_loader.setter
+    def str_loader(self, loader):
+        self._str_loader = loader
+
     def __init__(self, **kwargs):
         # Variables for sources reload (first load is also a reload).
         super(KebabSource, self).__init__(**kwargs)
@@ -56,6 +63,7 @@ class KebabSource(dict):
         self._reload_timer = None
         self._reload_disabled = threading.Event()
         self._cached_context = {}
+        self._str_loader = YamlLoader()
 
     def __repr__(self):
         return self.__class__.__name__
@@ -160,7 +168,7 @@ class KebabSource(dict):
                     function=self.reload,
                     args=(reload_interval_in_secs, False),
                 )
-                self._reload_timer.setDaemon(True)
+                self._reload_timer.daemon = True
                 self._reload_timer.start()
 
         return self
@@ -252,6 +260,15 @@ class KebabSource(dict):
 
         return config_value
 
+    @staticmethod
+    def _cast_bool(config_value: Any) -> bool:
+        if isinstance(config_value, str):
+            v = config_value.lower()
+            if v in ("1", "true", "yes", "on", "enable"):
+                return True
+            return False
+        return bool(config_value)
+
     @staticmethod
     def _cast(config_value, expected_type):
         """
@@ -272,7 +289,7 @@ class KebabSource(dict):
 
         The exceptions:
         1. If expected value is bool, it will only be True if the config_value (after
-            cast to str) is 'true', 'yes' and '1' (case insensitive)
+            cast to str) is 'true', 'yes' and '1' (case-insensitive)
         2. If expected value is list, it will be split by list_delimiter_char (default
             ',') (after cast to str)
 
@@ -285,13 +302,7 @@ class KebabSource(dict):
                 return expected_type()
             elif not isinstance(config_value, expected_type):
                 if expected_type == bool:
-                    # noinspection PyCompatibility
-                    if isinstance(config_value, str):
-                        v = config_value.lower()
-                        if v in ("1", "true", "yes", "on", "enable"):
-                            return True
-                        return False
-                    return bool(config_value)
+                    return KebabSource._cast_bool(config_value)
                 elif hasattr(expected_type, "__kebab_config__"):
                     return expected_type(literal(**config_value))
                 elif issubclass(expected_type, BaseModel):
@@ -399,7 +410,7 @@ class StrSource(KebabSource):
         self._content = content
 
     def _load_context(self):
-        return yaml.safe_load(self._content)
+        return self.str_loader.load(self._content)
 
 
 class UrlSource(KebabSource):
@@ -418,7 +429,7 @@ class UrlSource(KebabSource):
 
     def _load_context(self):
         content = self._opener.open(self._url).read()
-        return yaml.safe_load(content)
+        return self.str_loader.load(content)
 
 
 class DictSource(KebabSource):
@@ -568,7 +579,7 @@ def load_source(
     if urls_from_env:
         urls = urls_from_env.split(",")
 
-    sources = [UrlSource(url, opener=opener) for url in urls]  # type: List[KebabSource]
+    sources: List[KebabSource] = [UrlSource(url, opener=opener) for url in urls]
 
     if fallback_dict is not None and isinstance(fallback_dict, dict):
         sources.insert(0, DictSource(fallback_dict))
